Learn R Programming

CDNmoney (version 2005.6-1)

CanadianCreditData: Canadian Credit Aggregates

Description

Canadian credit aggregates.

Usage

data(CanadianCreditData)
	data(CanadianCreditData.asof.28Jan2005)

Arguments

format

The objects are time series.

source

Aggregates are from the Bank of Canada and also available from Statistics Canada.

Details

Several data objects are loaded, as listed in the table below. The CanadianCreditData usage loads the most recently version and other usages loads data as of a given date. These data are the Canadian Credit aggregates.

lll{ variable (ID) short description longer description TotalCredit total credit total household & business credit ConsumerCredit consumer credit total consumer credit ResidentialMortgage residential mortgage total residential mortgage credit ShortTermBusinessCredit short term-business credit total short-term business credit OtherBusinessCredit other business credit total other business credit }

The components in this database are not seasonally adjusted (SA), but the corresponding Bank of Canada / Statistics Canada Cansim II numbers for the seasonally adjusted aggregates are as follows:

ccc{ unadjusted SA TotalCredit v122644 v122648 ConsumerCredit v122698 v122707 ResidentialMortgage v122736 v122746 ShortTermBusinessCredit v122639 v122646 OtherBusinessCredit v36412 }

References

"Bank of Canada Banking and Financial Statistics table E2" http://www.bank-banque-canada.ca.

See Also

tframein the dse bundle of packages

Examples

Run this code
require("tframe")
 data("CanadianCreditData", package="CDNmoney")

 tfplot(TotalCredit, ConsumerCredit, ResidentialMortgage,
    ShortTermBusinessCredit, OtherBusinessCredit) 
 tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage,
    ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3 ) 

 tfplot(diff(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage,
    ShortTermBusinessCredit, OtherBusinessCredit)), graphs.per.page=3 ) 

 tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage,
    ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3, 
    start=c(1990,6), end=c(1991,6))

Run the code above in your browser using DataLab