data(CanadianMoneyData)
data(CanadianMoneyData.asof.5Jun2007)
data(CanadianMoneyData.asof.3Mar2006)
data(CanadianMoneyData.asof.28Jan2005)
data(CanadianMoneyData.asof.6Feb2004)
data(CanadianMoneyData.asof.26Aug2002)CanadianMoneyData usage loads the most recent version and
other usages loads data as of the given date.
These data are the components of the Canadian Monetary aggregates.
They have been "continuity adjusted" so that take-overs and mergers do
not result in breaks in the series. This involves re-arranging
historical data so that it reflects the current structure of the
industry. Trust company deposits are not included in some Canadian
monetary aggregates so, if a bank takes over a trust company, the
historical data for the trust company must be added to the bank's
historical data to eliminate a break in the series. The series start
at various dates but continuity adjustments prior to 1981 are not
complete. More details about the adjustment are provided
in Kottaras (2003).The originally released data is usually very accurate because of bank reporting requirements. Beware that continuity adjustments described above are the main reason for revisions to the data. For this reason the "as of" data may not be especially useful for some kinds of data revision studies.
In January 2007 the aggregates M1 gross and M1 total (sometimes called M1 net) were discontinued, and M2, M2+, M2++, and M3 were modified to "gross" versions. The earlier CanadianMoneyData sets contain these series, but more recent ones do not. Components as of January 2007 are as shown in table ''New Variable definitions''.
Table ''Composition of the Monetary Aggregates'' indicates how the components are added for the Bank of Canada monetary aggregates. This version of the table is for new monetary aggregates released in January 2007.
X means included; float is now included in all (gross) aggregates.
NetNonbankCheq = TMLCHEQPLUS + LCUCHEQPLUS - TMLinterbank;
NonbankNonCheq = TMLNCPLUSPLUS + LCUNCPLUSPLUS;
NetNonbankTotal= MV37235 + MV37239 - TMLinterbank;
use NetNonbankTotal = NonbankTerm + NonbankCheq + NetNonbankNonCheq
to get NonbankTerm = NetNonbankTotal - (NetNonbankCheq + NonbankNonCheq);
adjM1pp ( = adjV37210 - adjV37213 ) adjustment is only for data prior to the sample used in Gilbert and Pichette.
CUadj changes an estimate of NonbankNonCheq/NonbankTerm split prior
to April 1996. This only affects M1++.
Previously the components were defined using the B-number designations. The
variables were as shown in table ''Previously Components Definitions''.
The ''Previous Canadain Monetary Aggregates'' table indicates how these components were added for the Bank of
Canada monetary aggregates in the past. The column on the left indicates how they are
combined to form components for factor estimates as in Gilbert and Pichette (2003).
X- included + float is in - float is out NonbankCheq = TMLCHEQPLUS + LCUCHEQPLUS NonbankNonCheq = TMLNCPLUSPLUS + LCUNCPLUSPLUS NonbankTotal = NonbankTerm + NonbankCheq + NonbankNonCheq = MB2038M2P + MB2042 [actually NonbankTerm= NonbankTotal - (NonbankCheq + NonbankNonCheq ) ] MB473adj ( = MB473PLUSPLUS - MB473 )adjustment is only for data prior to the sample used in Gilbert and Pichette.
CUadj changes an estimate of NonbankNonCheq/NonbankTerm split prior
to April 1996. This only affects M1++.
Many of the MB numbers are related to B numbers from Statistics Canada's Cansim series identification system. The correspondence between these related B numbers and V number identifiers from the newer Statistics Canada Cansim II system is as shown in table ''Bank of Canada / Statistics Canada Cansim I and II numbers''.
The components in this database are not seasonally adjusted (SA), but the corresponding Bank of Canada / Statistics Canada numbers for the seasonally adjusted aggregates are as shown in table ''Monetary Aggregates and SA numbers''.
realM1
and percapitaM1.
Kottaras, J. (2003) The Construction of Continuity-Adjusted Monetary
Aggregate Components. Bank of Canada Working Paper 2003-22.
M1p <- tframed(V37173 + MV41552775 + MV41552777 + NetNonbankCheq + adjM1p, names="M1+ (V37258)")
M1pp <- tframed(CUadj + M1p + MV36818 + MV36828 + adjM1pp + NonbankNonCheq, names="gross M1++ (V37259)")
M2 <- tframed(V37173 + MV41552775 + MV41552777 + MV36818 + MV36828 + MV36823, names="gross M2 (V37198)")
M2p <- tframed(M2 + NetNonbankCheq + NonbankNonCheq + NonbankTerm + + V37243 + MV37244 + V37245, names="gross M2+ (V37216)")
M2pp <- tframed(M2p + V37255 + V37256, names="gross M2++ (V37257)")
M3 <- tframed(M2 + MV36830 + MV36876, names="gross M3 (V37197)")
######### Plot aggregates #####
tfplot(tbind(M1p, M1pp)) tfplot(tbind(M1pPerCapita, M1pReal)) tfplot(tbind(M2, M2p, M2pp)) tfplot(M3)
########### Calculations to get old monetary aggregates ###### data("CanadianMoneyData.asof.3Mar2006", package="CDNmoney")
#M1gross <- tframed(MB2001 + MB486 + MB487p + TMLinterbank, names="gross M1 (B2054)") M1p <- tframed(MB2001 + MB486 + MB487p + MB452 + MB452adj + MB472 + NonbankCheq, names="M1+ (B2060)") M1pp <- tframed(CUadj + M1p + MB453 + MB473 + MB473adj + NonbankNonCheq, names="M1++ (B2061)") M2 <- tframed(M1total + MB472 + MB473 + MB452 + MB453 + MB454, names="M2 (B2031)") M2p <- tframed(M2 + NonbankCheq + NonbankNonCheq + NonbankTerm + MB2046 + MB2047 + MB2048, names="M2+ (B2037)") M2pp <- tframed(M2p + MB2057 + MB2058, names="M2++ (B2059)") M3 <- tframed(M2 + MB475 + MB482, names="M3 (B2030)")
######### Calculations of cpi and pop ######
# M1real = M1total * 100/p100000 (CPI - p20 Bank of Canada Weekly Financial # Statistics, June 1992=100) # M1PerCapita = M1total * 100 /(pop * p100000) # using a quarterly population # series converted to monthly using spline. # cpi <- 100 * M1total / M1real # seriesNames(cpi) <- "CPI" # popm <- M1total / M1PerCapita # seriesNames(popm) <- "Population of Canada"
cpi <- 100 * M1p / M1pReal seriesNames(cpi) <- "CPI" popm <- M1p / M1pPerCapita seriesNames(popm) <- "Population of Canada"
######### Plot aggregates #####
#tfplot(tbind(M1total, M1gross, M1p, M1pp)) tfplot(tbind(M1p, M1pp)) tfplot(tbind(M1pPerCapita, M1pReal)) tfplot(tbind(M2, M2p, M2pp)) tfplot(M3)
#### Calculations to get components as used in Gilbert and Pichette #### data("CanadianMoneyData.asof.3Mar2006", package="CDNmoney")
z <-tfwindow(tframed(tbind( MB2001, MB486 + MB452 , NonbankCheq, MB472 + MB473 + MB487p, MB475, NonbankNonCheq + MB454 + NonbankTerm + MB2046 + MB2047 + MB2048 + MB2057 + MB2058 + MB482 + MB453), names=c("currency", "personal cheq.", "NonbankCheq", "N-P demand & notice", "N-P term", "Investment") ), start=c(1986,1), end=c(2002,4))
MBcomponents <- 1e8 * z /matrix(tfwindow(popm * cpi, start=c(1986,1), end=c(2002,4)),196, 6) # 1e8 * gives real $ per person #(MB numbers in millions, CPI in fraction*100, popm in persons.)
tfplot(MBcomponents, graphs.per.page=3)
CanadianCreditData,
tframein the dse bundle of packages