Learn R Programming

CDNmoney (version 2007.6-1)

CanadianCreditData: Canadian Credit Aggregates

Description

Canadian credit aggregates.

Usage

data(CanadianCreditData)
	data(CanadianCreditData.asof.5Jun2007)
	data(CanadianCreditData.asof.3Mar2006)
	data(CanadianCreditData.asof.28Jan2005)

Arguments

format

The objects are time series.

Details

Several data objects are loaded, as listed in the table ''Canadian Credit Variable Definitions''. The CanadianCreditData usage loads the most recent version and other usages loads data as of the given date. These data are the Canadian Credit aggregates in millions of Canadian dollars. table Canadian Credit Variable Definitions center tabular{lll} variable (ID) short description longer description TotalCredit total credit total household and business credit ConsumerCredit consumer credit total consumer credit ResidentialMortgage residential mortgage total residential mortgage credit ShortTermBusinessCredit short term-business credit total short-term business credit OtherBusinessCredit other business credit total other business credit tabular center table

The components in this database are not seasonally adjusted (SA), but the corresponding Bank of Canada / Statistics Canada Cansim II numbers for the seasonally adjusted aggregates are as as shown in table ''Bank of Canada / Statistics Canada Cansim II numbers''.

table Bank of Canada / Statistics Canada Cansim II numbers center tabular{lll} unadjusted SA TotalCredit v122644 v122648 ConsumerCredit v122698 v122707 ResidentialMortgage v122736 v122746 ShortTermBusinessCredit v122639 v122646 OtherBusinessCredit v36412 tabular center table

Aggregates are from the Bank of Canada and also available from Statistics Canada.

Bank of Canada Banking and Financial Statistics. Table E2 http://www.bank-banque-canada.ca.

require("tframe") data("CanadianCreditData", package="CDNmoney")

tfplot(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit) tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3 )

tfplot(diff(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit)), graphs.per.page=3 )

tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3, start=c(1990,6), end=c(1991,6))

CanadianMoneyData, tframe datasets