data(CanadianCreditData)
data(CanadianCreditData.asof.5Jun2007)
data(CanadianCreditData.asof.3Mar2006)
data(CanadianCreditData.asof.28Jan2005)CanadianCreditData usage loads the most recent version and
other usages loads data as of the given date.
These data are the Canadian Credit aggregates in millions of Canadian
dollars.
The components in this database are not seasonally adjusted (SA), but the corresponding Bank of Canada / Statistics Canada Cansim II numbers for the seasonally adjusted aggregates are as as shown in table ''Bank of Canada / Statistics Canada Cansim II numbers''.
tfplot(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit) tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3 )
tfplot(diff(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit)), graphs.per.page=3 )
tfplot(tbind(TotalCredit, ConsumerCredit, ResidentialMortgage, ShortTermBusinessCredit, OtherBusinessCredit), graphs.per.page=3, start=c(1990,6), end=c(1991,6))
CanadianMoneyData,
tframe