data(CanadianMoneyData)
data(CanadianMoneyData.asof.28Jan2005)
data(CanadianMoneyData.asof.6Feb2004)
data(CanadianMoneyData.asof.26Aug2002)CanadianMoneyData usage loads the most recently version and
other usages loads data as of a given date.
These data are the components of the Canadian Monetary aggregates.
They have been "continuity adjusted" so that take-overs and mergers do
not result in breaks in the series. This involves re-arranging
historical data so that it reflects the current structure of the
industry. Trust company deposits are not included in some Canadian
monetary aggregates so, if a bank takes over a trust company, the
historical data for the trust company must be added to the bank's
historical data to eliminate a break in the series. The series start
at various dates but continuity adjustments prior to 1981 are not
complete. More details about the adjustment are provided
in Kottaras (2003).The originally released data is usually very accurate because of bank reporting requirements. Beware that continuity adjustments described above are the main reason for revisions to the data. For this reason the "as of" data may not be especially useful for some kinds of data revision studies.
The following table indicates how these components are added for the Bank of
Canada monetary aggregates. The column on the left indicates how they are
combined to form components for factor estimates as in Gilbert and Pichette (2003).
X- included + float is in - float is out NonbankCheq = TMLCHEQPLUS + LCUCHEQPLUS NonbankNonCheq = TMLNCPLUSPLUS + LCUNCPLUSPLUS NonbankTotal = NonbankTerm + NonbankCheq + NonbankNonCheq = MB2038M2P + MB2042 [actually NonbankTerm= NonbankTotal - (NonbankCheq + NonbankNonCheq ) ] MB473adj ( = MB473PLUSPLUS - MB473 )adjustment is only for data prior to the sample used in Gilbert and Pichette.
CUadj changes an estimate of NonbankNonCheq/NonbankTerm split prior to April 1996. This only affects M1++.
Many of the MB numbers are related to B numbers from Statistics Canada's Cansim series identification system. The correspondence between these related B numbers and V number identifiers from the newer Statistics Canada Cansim II system is as follows:
The components in this database are not seasonally adjusted (SA), but the corresponding Bank of Canada / Statistics Canada numbers for the seasonally adjusted aggregates are as follows:
realM1
and percapitaM1.
Kottaras, J. (2003) "The Construction of Continuity-Adjusted Monetary
Aggregate Components." Bank of Canada Working Paper 2003-22.
M1gross <- tframed(MB2001 + MB486 + MB487p + TMLinterbank, names="gross M1 (B2054)") M1p <- tframed(MB2001 + MB486 + MB487p + MB452 + MB452adj + MB472 + NonbankCheq, names="M1+ (B2060)") M1pp <- tframed(CUadj + M1p + MB453 + MB473 + MB473adj + NonbankNonCheq, names="M1++ (B2061)") M2 <- tframed(M1total + MB472 + MB473 + MB452 + MB453 + MB454, names="M2 (B2031)") M2p <- tframed(M2 + NonbankCheq + NonbankNonCheq + NonbankTerm + MB2046 + MB2047 + MB2048, names="M2+ (B2037)") M2pp <- tframed(M2p + MB2057 + MB2058, names="M2++ (B2059)") M3 <- tframed(M2 + MB475 + MB482, names="M3 (B2030)")
######### Calculations of cpi and pop ######
# M1real = M1total * 100/p100000 (CPI - p20 Bank of Canada Weekly Financial # Statistics, June 1992=100) # M1PerCapita = M1total * 100 /(pop * p100000) # using a quarterly population # series converted to monthly using spline. cpi <- 100 * M1total / M1real seriesNames(cpi) <- "CPI" popm <- M1total / M1PerCapita seriesNames(popm) <- "Population of Canada"
######### Plot aggregates #####
tfplot(tbind(M1total, M1gross, M1p, M1pp)) tfplot(tbind(M1PerCapita, M1real)) tfplot(tbind(M2, M2p, M2pp)) tfplot(M3)
#### Calculations to get components as used in Gilbert and Pichette ####
z <-tfwindow(tframed(tbind( MB2001, MB486 + MB452 , NonbankCheq, MB472 + MB473 + MB487p, MB475, NonbankNonCheq + MB454 + NonbankTerm + MB2046 + MB2047 + MB2048 + MB2057 + MB2058 + MB482 + MB453), names=c("currency", "personal cheq.", "NonbankCheq", "N-P demand & notice", "N-P term", "Investment") ), start=c(1986,1), end=c(2002,4))
MBcomponents <- 1e8 * z /matrix(tfwindow(popm * cpi, start=c(1986,1), end=c(2002,4)),196, 6) # 1e8 * gives real $ per person #(MB numbers in millions, CPI in fraction*100, popm in persons.)
tfplot(MBcomponents, graphs.per.page=3)
tframein the dse bundle of packages